
    create table animatorright (
        programmeid varchar(255) not null,
        restricteduserid varchar(255) not null,
        primary key (restricteduserid, programmeid)
    )

    create table archive (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        starttimestamp bigint not null,
        channelid varchar(255) not null,
        playlist varchar(255),
        timetableslot varchar(255),
        duration bigint not null,
        playlistcaption varchar(255),
        programmecaption varchar(255),
        track varchar(255),
        authorcaption varchar(255),
        titlecaption varchar(255),
        albumcaption varchar(255),
        publishercaption varchar(255),
        copyrightcaption varchar(255),
        requester varchar(255),
        broadcastercaption varchar(255),
        primary key (refid),
        unique (starttimestamp, channelid)
    )

    create table channel (
        label varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        description varchar(255),
        timezone varchar(255) not null,
        maxdailyrequestlimitperuser integer,
        url varchar(255),
        tag varchar(255),
        openregistration smallint not null,
        streamitem varchar(255),
        seatnumber bigint,
        primary key (label)
    )

    create table channeladministratorright (
        channelid varchar(255) not null,
        restricteduserid varchar(255) not null,
        primary key (restricteduserid, channelid)
    )

    create table channeljournal (
        channelid varchar(255) not null,
        logid varchar(255) not null,
        primary key (channelid, logid)
    )

    create table contributorright (
        programmeid varchar(255) not null,
        restricteduserid varchar(255) not null,
        primary key (restricteduserid, programmeid)
    )

    create table curatorright (
        programmeid varchar(255) not null,
        restricteduserid varchar(255) not null,
        primary key (restricteduserid, programmeid)
    )

    create table filter (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        slotid varchar(255),
        include smallint not null,
        mixedfeature varchar(255),
        contains varchar(255),
        numericfeature varchar(255),
        minimum smallint,
        maximum smallint,
        categoryfeature varchar(255),
        primary key (refid)
    )

    create table hit (
        apikey varchar(255) not null,
        timestamp bigint not null,
        version integer not null,
        primary key (apikey, timestamp)
    )

    create table journal (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        logtimestamp bigint not null,
        actor varchar(255),
        actee varchar(255),
        action varchar(255),
        friendlyplaylistlabel varchar(255),
        slottimestamp bigint,
        channellabel varchar(255),
        friendlytrackauthorlabel varchar(255),
        friendlytracktitlelabel varchar(255),
        archivetimestamp bigint,
        reportstarttimestamp bigint,
        reportendtimestamp bigint,
        friendlyexceptionlabel varchar(255),
        primary key (refid)
    )

    create table listenerright (
        channelid varchar(255) not null,
        restricteduserid varchar(255) not null,
        primary key (restricteduserid, channelid)
    )

    create table notification (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        logtimestamp bigint not null,
        actor varchar(255),
        freetext varchar(255),
        recipientnotified smallint not null,
        recipientid varchar(255) not null,
        sourceid varchar(255) for bit data,
        destinationid varchar(255) for bit data,
        action varchar(255),
        slottimestamp bigint,
        channellabel varchar(255),
        archivetimestamp bigint,
        reportstarttimestamp bigint,
        reportendtimestamp bigint,
        queueitemtimestamp bigint,
        entityid varchar(255) for bit data,
        friendlytrackauthorlabel varchar(255),
        friendlytracktitlelabel varchar(255),
        friendlyplaylistlabel varchar(255),
        primary key (refid)
    )

    create table people (
        login varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        realname varchar(255),
        password varchar(255) not null,
        email varchar(255) not null,
        enabled smallint not null,
        timezone varchar(255) not null,
        email_notification smallint not null,
        primary key (login)
    )

    create table playlist (
        refid varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        label varchar(255),
        description varchar(255),
        maxuserrequestlimit integer,
        norequestreplaydelay bigint,
        norequestreplayinplaylist smallint not null,
        ready smallint not null,
        picture_format varchar(255),
        picture_size bigint,
        programmeid varchar(255) not null,
        live_broadcaster varchar(255),
        live_login varchar(255),
        live_password varchar(255),
        advisory_age varchar(255),
        advisory_violence smallint,
        advisory_profanity smallint,
        advisory_fear smallint,
        advisory_sex smallint,
        advisory_drugs smallint,
        advisory_discrimination smallint,
        author_tag varchar(255),
        title_tag varchar(255),
        album_tag varchar(255),
        genre_tag varchar(255),
        dateofrelease_tag smallint,
        description_tag varchar(255),
        copyright_tag varchar(255),
        advisory_age_tag varchar(255),
        advisory_violence_tag smallint,
        advisory_profanity_tag smallint,
        advisory_fear_tag smallint,
        advisory_sex_tag smallint,
        advisory_drugs_tag smallint,
        advisory_discrimination_tag smallint,
        primary key (refid)
    )

    create table programme (
        label varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        description varchar(255),
        metainfoPattern varchar(255),
        overlappingplaylistallowed smallint not null,
        primary key (label)
    )

    create table programmechannel (
        channelid varchar(255) not null,
        programmeid varchar(255) not null,
        primary key (channelid, programmeid)
    )

    create table programmemanagerright (
        channelid varchar(255) not null,
        restricteduserid varchar(255) not null,
        primary key (restricteduserid, channelid)
    )

    create table queue (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        channelid varchar(255) not null,
        sequenceindex bigint not null,
        pooled smallint not null,
        likelystarttimestamp bigint not null,
        likelyduration bigint not null,
        timemarkeratend bigint,
        playlistfadein integer,
        timetableid varchar(255),
        trackid varchar(255),
        playlistsequenceindex bigint,
        playlistloopindex bigint,
        naturalduration bigint,
        primary key (refid)
    )

    create table report (
        refid varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        starttimestamp bigint not null,
        stoptimestamp bigint not null,
        channelid varchar(255) not null,
        text_format varchar(255),
        text_size bigint,
        ready smallint not null,
        primary key (refid),
        unique (starttimestamp, stoptimestamp, channelid)
    )

    create table request (
        refid varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        songid varchar(255),
        channelid varchar(255) not null,
        requesterid varchar(255),
        streamitem varchar(255),
        queueitem varchar(255),
        message varchar(255),
        primary key (refid)
    )

    create table slot (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        playlistid varchar(255) not null,
        sequenceindex bigint not null,
        fadein integer,
        repeatloop bigint,
        request smallint not null,
        trackid varchar(255),
        selection varchar(255),
        sort varchar(255),
        limitstart bigint,
        limitend bigint,
        noreplaydelay bigint,
        noreplayinplaylist smallint,
        primary key (refid)
    )

    create table stream (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        starttimestamp bigint not null,
        likelyduration bigint not null,
        queueid varchar(255),
        trackid varchar(255),
        primary key (refid)
    )

    create table timetableslot (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        starttimestamp bigint not null,
        channelid varchar(255) not null,
        enabled smallint not null,
        streamitem varchar(255),
        programmeid varchar(255) not null,
        playlistid varchar(255),
        endtimestamp bigint,
        decommissioningtimestamp bigint,
        startmillisecondfromperiod bigint,
        endmillisecondfromperiod bigint,
        primary key (refid),
        unique (starttimestamp, channelid)
    )

    create table track (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        author varchar(255) not null,
        title varchar(255) not null,
        ready smallint not null,
        album varchar(255),
        genre varchar(255),
        dateofrelease smallint,
        description varchar(255),
        publisher varchar(255),
        copyright varchar(255),
        tag varchar(255),
        advisory_age varchar(255),
        advisory_violence smallint,
        advisory_profanity smallint,
        advisory_fear smallint,
        advisory_sex smallint,
        advisory_drugs smallint,
        advisory_discrimination smallint,
        audio_format varchar(255),
        audio_size bigint,
        audio_duration float,
        audio_bitrate bigint,
        audio_samplerate integer,
        audio_channels smallint,
        audio_vbr smallint,
        picture_format varchar(255),
        picture_size bigint,
        enabled smallint,
        primary key (refid)
    )

    create table trackprogramme (
        refid varchar(255) not null,
        type varchar(255) not null,
        version integer not null,
        rotation bigint,
        trackid varchar(255) not null,
        programmeid varchar(255) not null,
        primary key (refid)
    )

    create table voting (
        refid varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        songid varchar(255) not null,
        restricteduserid varchar(255) not null,
        value smallint not null,
        primary key (refid),
        unique (songid, restricteduserid)
    )

    create table webservice (
        apikey varchar(255) not null,
        version integer not null,
        creation timestamp not null,
        creator varchar(255),
        latestmodification timestamp,
        latesteditor varchar(255),
        channelid varchar(255) not null,
        maxfirerate bigint,
        maxdailylimit bigint,
        privatekey varchar(255) not null,
        whitelistregexp varchar(255),
        nowplayingmodule smallint not null,
        comingnextmodule smallint not null,
        timetablemodule smallint not null,
        votemodule smallint not null,
        archivemodule smallint not null,
        requestmodule smallint not null,
        primary key (apikey)
    )

    alter table animatorright 
        add constraint FKBBD74F958810107F 
        foreign key (programmeid) 
        references programme

    alter table animatorright 
        add constraint FKBBD74F954F94DE48 
        foreign key (restricteduserid) 
        references people

    alter table animatorright 
        add constraint FKBBD74F95B4418FAD 
        foreign key (restricteduserid) 
        references people

    alter table archive 
        add constraint FKD368E0C2AC74AA78 
        foreign key (creator) 
        references people

    alter table archive 
        add constraint FKD368E0C29D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table archive 
        add constraint FKD368E0C2C528BF4 
        foreign key (channelid) 
        references channel 
        on delete cascade

    alter table channel 
        add constraint FK2C0B7D038659E265 
        foreign key (streamitem) 
        references stream

    alter table channel 
        add constraint FK2C0B7D03AC74AA78 
        foreign key (creator) 
        references people

    alter table channel 
        add constraint FK2C0B7D039D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table channeladministratorright 
        add constraint FK6CB819B24F94DE48 
        foreign key (restricteduserid) 
        references people

    alter table channeladministratorright 
        add constraint FK6CB819B2B4418FAD 
        foreign key (restricteduserid) 
        references people

    alter table channeladministratorright 
        add constraint FK6CB819B2C528BF4 
        foreign key (channelid) 
        references channel

    alter table channeljournal 
        add constraint FK178618D49F4505EA 
        foreign key (logid) 
        references journal

    alter table channeljournal 
        add constraint FK178618D4C528BF4 
        foreign key (channelid) 
        references channel

    alter table contributorright 
        add constraint FKE360B2218810107F 
        foreign key (programmeid) 
        references programme

    alter table contributorright 
        add constraint FKE360B2214F94DE48 
        foreign key (restricteduserid) 
        references people

    alter table contributorright 
        add constraint FKE360B221B4418FAD 
        foreign key (restricteduserid) 
        references people

    alter table curatorright 
        add constraint FKC7B754468810107F 
        foreign key (programmeid) 
        references programme

    alter table curatorright 
        add constraint FKC7B754464F94DE48 
        foreign key (restricteduserid) 
        references people

    alter table curatorright 
        add constraint FKC7B75446B4418FAD 
        foreign key (restricteduserid) 
        references people

    alter table filter 
        add constraint FKB408CB7861F1E934 
        foreign key (slotid) 
        references slot 
        on delete cascade

    alter table hit 
        add constraint FK19393AFE52351 
        foreign key (apikey) 
        references webservice 
        on delete cascade

    alter table listenerright 
        add constraint FK24BDCDE84F94DE48 
        foreign key (restricteduserid) 
        references people

    alter table listenerright 
        add constraint FK24BDCDE8B4418FAD 
        foreign key (restricteduserid) 
        references people

    alter table listenerright 
        add constraint FK24BDCDE8C528BF4 
        foreign key (channelid) 
        references channel

    alter table notification 
        add constraint FK237A88EBC318F0FB 
        foreign key (recipientid) 
        references people 
        on delete cascade

    alter table people 
        add constraint FKC4E2328FAC74AA78 
        foreign key (creator) 
        references people

    alter table people 
        add constraint FKC4E2328F9D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table playlist 
        add constraint FK700681D28810107F 
        foreign key (programmeid) 
        references programme 
        on delete cascade

    alter table playlist 
        add constraint FK700681D2AC74AA78 
        foreign key (creator) 
        references people

    alter table playlist 
        add constraint FK700681D29D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table programme 
        add constraint FKC6419B1CAC74AA78 
        foreign key (creator) 
        references people

    alter table programme 
        add constraint FKC6419B1C9D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table programmechannel 
        add constraint FKBD766A678810107F 
        foreign key (programmeid) 
        references programme

    alter table programmechannel 
        add constraint FKBD766A67C528BF4 
        foreign key (channelid) 
        references channel

    alter table programmemanagerright 
        add constraint FK223C47AB4F94DE48 
        foreign key (restricteduserid) 
        references people

    alter table programmemanagerright 
        add constraint FK223C47ABB4418FAD 
        foreign key (restricteduserid) 
        references people

    alter table programmemanagerright 
        add constraint FK223C47ABC528BF4 
        foreign key (channelid) 
        references channel

    alter table queue 
        add constraint FK66F1911250E382C 
        foreign key (timetableid) 
        references timetableslot 
        on delete cascade

    alter table queue 
        add constraint FK66F1911CFBDDFDB 
        foreign key (trackid) 
        references track 
        on delete cascade

    alter table queue 
        add constraint FK66F1911C528BF4 
        foreign key (channelid) 
        references channel 
        on delete cascade

    alter table report 
        add constraint FKC84C5534AC74AA78 
        foreign key (creator) 
        references people

    alter table report 
        add constraint FKC84C55349D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table report 
        add constraint FKC84C5534C528BF4 
        foreign key (channelid) 
        references channel

    alter table request 
        add constraint FK414EF28F7B5C3547 
        foreign key (streamitem) 
        references stream

    alter table request 
        add constraint FK414EF28FAC74AA78 
        foreign key (creator) 
        references people

    alter table request 
        add constraint FK414EF28F9D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table request 
        add constraint FK414EF28F8960499E 
        foreign key (requesterid) 
        references people

    alter table request 
        add constraint FK414EF28F46EA69DB 
        foreign key (songid) 
        references track

    alter table request 
        add constraint FK414EF28F85A9471A 
        foreign key (songid) 
        references track

    alter table request 
        add constraint FK414EF28F9547BDF7 
        foreign key (songid) 
        references track

    alter table request 
        add constraint FK414EF28FC528BF4 
        foreign key (channelid) 
        references channel

    alter table request 
        add constraint FK414EF28FFA821798 
        foreign key (queueitem) 
        references queue

    alter table slot 
        add constraint FK35E9FE770C7D19 
        foreign key (playlistid) 
        references playlist 
        on delete cascade

    alter table slot 
        add constraint FK35E9FECFBDDFDB 
        foreign key (trackid) 
        references track 
        on delete cascade

    alter table stream 
        add constraint FKCAD54F80CFBDDFDB 
        foreign key (trackid) 
        references track 
        on delete cascade

    alter table timetableslot 
        add constraint FK8B1D129F8659E265 
        foreign key (streamitem) 
        references stream

    alter table timetableslot 
        add constraint FK8B1D129F8810107F 
        foreign key (programmeid) 
        references programme 
        on delete cascade

    alter table timetableslot 
        add constraint FK8B1D129F770C7D19 
        foreign key (playlistid) 
        references playlist

    alter table timetableslot 
        add constraint FK8B1D129FAC74AA78 
        foreign key (creator) 
        references people

    alter table timetableslot 
        add constraint FK8B1D129F9D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table timetableslot 
        add constraint FK8B1D129FC528BF4 
        foreign key (channelid) 
        references channel 
        on delete cascade

    alter table track 
        add constraint FK697F14BAC74AA78 
        foreign key (creator) 
        references people

    alter table track 
        add constraint FK697F14B9D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table trackprogramme 
        add constraint FKEE8CEE318810107F 
        foreign key (programmeid) 
        references programme

    alter table trackprogramme 
        add constraint FKEE8CEE3164D4190C 
        foreign key (trackid) 
        references track

    alter table voting 
        add constraint FKCFAE5D27AC74AA78 
        foreign key (creator) 
        references people

    alter table voting 
        add constraint FKCFAE5D279D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table voting 
        add constraint FKCFAE5D274F94DE48 
        foreign key (restricteduserid) 
        references people 
        on delete cascade

    alter table voting 
        add constraint FKCFAE5D2746EA69DB 
        foreign key (songid) 
        references track

    alter table voting 
        add constraint FKCFAE5D2785A9471A 
        foreign key (songid) 
        references track

    alter table voting 
        add constraint FKCFAE5D279547BDF7 
        foreign key (songid) 
        references track

    alter table webservice 
        add constraint FK479A54E1AC74AA78 
        foreign key (creator) 
        references people

    alter table webservice 
        add constraint FK479A54E19D8CDA00 
        foreign key (latesteditor) 
        references people

    alter table webservice 
        add constraint FK479A54E1C528BF4 
        foreign key (channelid) 
        references channel 
        on delete cascade
